aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/0x.js.ts8
-rw-r--r--src/utils/assert.ts4
-rw-r--r--src/web3_wrapper.ts8
3 files changed, 10 insertions, 10 deletions
diff --git a/src/utils/assert.ts b/src/utils/assert.ts
index 6e10c5d40..5b4a6fca6 100644
--- a/src/utils/assert.ts
+++ b/src/utils/assert.ts
@@ -29,9 +29,9 @@ export const assert = {
async isSenderAddressHexAsync(variableName: string, senderAddress: string,
web3Wrapper: Web3Wrapper): Promise<void> {
assert.isETHAddressHex(variableName, senderAddress);
- await assert.isSenderAccountAvailableAsync(web3Wrapper, senderAddress);
+ await assert.isSenderAddressAvailableAsync(web3Wrapper, senderAddress);
},
- async isSenderAccountAvailableAsync(web3Wrapper: Web3Wrapper, senderAddress: string): Promise<void> {
+ async isSenderAddressAvailableAsync(web3Wrapper: Web3Wrapper, senderAddress: string): Promise<void> {
const isSenderAddressAvailable = await web3Wrapper.isSenderAddressAvailableAsync(senderAddress);
assert.assert(isSenderAddressAvailable, `Specified sender account ${senderAddress} isn't available through the \
supplied web3 instance`);
diff --git a/src/web3_wrapper.ts b/src/web3_wrapper.ts
index 2508c5116..e1bb29f85 100644
--- a/src/web3_wrapper.ts
+++ b/src/web3_wrapper.ts
@@ -17,14 +17,14 @@ export class Web3Wrapper {
public isAddress(address: string): boolean {
return this.web3.isAddress(address);
}
- public getDefaultAccount(): string {
+ public getDefaultAddress(): string {
return this.web3.eth.defaultAccount;
}
- public setDefaultAccount(address: string): void {
+ public setDefaultAddress(address: string): void {
this.web3.eth.defaultAccount = address;
}
public async isSenderAddressAvailableAsync(senderAddress: string): Promise<boolean> {
- const addresses = await this.getAvailableAccountsAsync();
+ const addresses = await this.getAvailableAddressesAsync();
return _.includes(addresses, senderAddress);
}
public async getNodeVersionAsync(): Promise<string> {
@@ -61,7 +61,7 @@ export class Web3Wrapper {
const {timestamp} = await promisify(this.web3.eth.getBlock)(blockHash);
return timestamp;
}
- public async getAvailableAccountsAsync(): Promise<string[]> {
+ public async getAvailableAddressesAsync(): Promise<string[]> {
const addresses: string[] = await promisify(this.web3.eth.getAccounts)();
return addresses;
}
diff --git a/src/0x.js.ts b/src/0x.js.ts
index 0d8e30d8c..84362bd9a 100644
--- a/src/0x.js.ts
+++ b/src/0x.js.ts
@@ -122,11 +122,11 @@ export class ZeroEx {
this.token.invalidateContractInstances();
}
/**
* Get accounts via the supplied web3 instance available for sending transactions.
*/
- public async getAvailableAccountsAsync(): Promise<string[]> {
- const availableAccounts = await this.web3Wrapper.getAvailableAccountsAsync();
- return availableAccounts;
+ public async getAvailableAddressesAsync(): Promise<string[]> {
+ const availableAddresses = await this.web3Wrapper.getAvailableAddressesAsync();
+ return availableAddresses;
}
/**
* Computes the orderHash for a given order and returns it as a hex encoded string.
@@ -122,11 +122,11 @@ export class ZeroEx {
}
/**
- * Get accounts via the supplied web3 instance available for sending transactions.
+ * Get addresses via the supplied web3 instance available for sending transactions.
*/